# ZacrosTools

ZacrosTools is a simple toolkit for the preparation of **[Zacros](https://zacros.org/)** input files. It is specially 
useful when running scans at different pressure and temperature conditions, which may require hundreds of KMC 
simulations.

## Installation

The easiest way to install ZacrosTools is by using pip:

    $ pip install zacrostools

Alternatively, it can also be cloned from [GitHub](https://github.com/hprats/ZacrosTools):

    $ git clone https://github.com/hprats/ZacrosTools.git

The only requirements are [scipy](https://scipy.org/) and [pandas](https://pandas.pydata.org/).

